import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';

const flyoutCss = ":host .flyout{box-sizing:border-box;list-style:none;background-color:#f5f5f5;border-color:#ddd;line-height:1.5;letter-spacing:0.5px;text-decoration:none;font:16px Arial, sans-serif;padding-top:10px;padding-bottom:10px;border-radius:4px;border-width:1px;box-shadow:2px 2px 4px rgba(0, 0, 0, 0.2)}";

const isHTMLAbcFlyoutItemElement = (element) => {
    if (typeof element === 'object' && typeof element.item === 'string') {
        return true;
    }
    return false;
};
const Flyout = /*@__PURE__*/ proxyCustomElement(class Flyout extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.flyoutChange = createEvent(this, "flyoutChange", 7);
        this.selectedItem = undefined;
    }
    onFlyoutChange() {
        this.flyoutChange.emit(this.selectedItem);
    }
    async handleKeyDown(e) {
        if (!(e.key === 'ArrowDown' || e.key === 'ArrowUp')) {
            return;
        }
        const items = this.items;
        let currentIndex = items.findIndex((item) => item === document.activeElement);
        if (currentIndex === -1) {
            return;
        }
        if (e.key === 'ArrowDown') {
            currentIndex = (currentIndex + 1) % items.length;
        }
        else if (e.key === 'ArrowUp') {
            currentIndex = (currentIndex - 1 + items.length) % items.length;
        }
        await items[currentIndex].focusItem();
        e.preventDefault();
    }
    select(item) {
        if (this.selectedItem === item) {
            return false;
        }
        this.selectedItem = item;
        return true;
    }
    get items() {
        return Array.from(this.host.querySelectorAll('abc-flyout-item'));
    }
    getItems(item) {
        return isHTMLAbcFlyoutItemElement(item) ? item : this.items.find((t) => t.item === item);
    }
    componentWillRender() {
        const selectedItem = this.getItems(this.selectedItem);
        this.items.forEach((item) => {
            item.selected = false;
        });
        if (selectedItem) {
            selectedItem.selected = true;
        }
    }
    render() {
        return (h(Host, { onItemClick: ({ detail: { item } }) => {
                this.select(item);
            } }, h("div", { class: "flyout" }, h("slot", null))));
    }
    get host() { return this; }
    static get watchers() { return {
        "selectedItem": ["onFlyoutChange"]
    }; }
    static get style() { return flyoutCss; }
}, [1, "abc-flyout", {
        "selectedItem": [513, "selected-item"]
    }, [[10, "keydown", "handleKeyDown"]], {
        "selectedItem": ["onFlyoutChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["abc-flyout"];
    components.forEach(tagName => { switch (tagName) {
        case "abc-flyout":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, Flyout);
            }
            break;
    } });
}

const AbcFlyout = Flyout;
const defineCustomElement = defineCustomElement$1;

export { AbcFlyout, defineCustomElement };

//# sourceMappingURL=abc-flyout.js.map